@@ -15,7 +15,7 @@
 #include <QPointer>
 #include <QTimer>
 
-#include <QCoroCore>
+#include <QCoroTask>
 
 class ConnectivityMonitor : public QObject
 {
@@ -24,9 +24,11 @@ public:
     explicit ConnectivityMonitor(QObject *parent);
     ~ConnectivityMonitor() override;
 
+    void cancelLimitedConnectivityNotificationTimer();
+
 private Q_SLOTS:
     void connectivityChanged(NetworkManager::Connectivity connectivity);
-    QCoro::Task<void> checkConnectivity();
+    QCoro::Task<> checkConnectivity();
 
 private:
     void showLimitedConnectivityNotification();
