@@ -178,23 +178,14 @@ void TeamWidget::deleteTeam()
 
     if (connection) {
         qCDebug(PLASMA_NM_EDITOR_LOG) << "About to delete teamed connection" << currentItem->text() << uuid;
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (KMessageBox::questionTwoActions(this,
-#else
-        if (KMessageBox::questionYesNo(this,
-
-#endif
                                             i18n("Do you want to remove the connection '%1'?", connection->name()),
                                             i18n("Remove Connection"),
                                             KStandardGuiItem::remove(),
                                             KStandardGuiItem::cancel(),
                                             QString(),
                                             KMessageBox::Dangerous)
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-            == KMessageBox::Yes) {
-#endif
             connection->remove();
             delete currentItem;
             slotWidgetChanged();
@@ -241,3 +232,5 @@ bool TeamWidget::isValid() const
 {
     return !m_ui->ifaceName->text().isEmpty() && m_ui->teams->count() > 0;
 }
+
+#include "moc_teamwidget.cpp"
