@@ -6,8 +6,8 @@
 
 #include "simpleiplistvalidator.h"
 
+#include <QList>
 #include <QStringList>
-#include <QVector>
 
 SimpleIpListValidator::SimpleIpListValidator(AddressStyle style, AddressType type, QObject *parent)
     : QValidator(parent)
@@ -86,3 +86,5 @@ QValidator::State SimpleIpListValidator::validate(QString &address, int &pos) co
     }
     return result;
 }
+
+#include "moc_simpleiplistvalidator.cpp"
